NAME

Apache::AuthenURL - authenticates via another URL

SYNOPSIS

#in .htaccess
AuthName MyHTTPAuth
AuthType Basic
PerlAuthenHandler Apache::AuthenCache Apache::AuthenURL::handler Apache::AuthenCache::manage_cache

PerlSetVar AuthenURL_method HEAD		# a valid LWP method
PerlSetVar AuthenURL_url https://somehost
PerlSetVar AuthenURL_proxy http://someproxy:port
PerlSetVar AuthenCache_cache_time	

Options Indexes FollowSymLinks ExecCGI
 
require valid-user

DESCRIPTION

I wrote this module to work around the lack of DCE support for Solaris x86. DCE authentication in my application is handled using Gradient's DCE plug-in for Netscape Enterprise Server. The request is encrypted using SSL.

ACKNOWLEDGEMENTS

The cache code was heavily borrowed from Apache::AuthenDBI by Edmund Mergl <E.Mergl@bawue.de>, but now has been stripped out in favor of the more general solution in Apache::AuthenCache by Jason Bodnar <jason@shakabuku.org>.

SEE ALSO

mod_perl(1), Apache::AuthenCache(3), LWP(3)

AUTHOR

John Groenveld <groenveld@acm.org>

COPYRIGHT

This package is Copyright (C) 1998 by John Groenveld. It may be copied, used and redistributed under the same terms as perl itself.