NAME

Apache::Session::Browseable::Store::Redis - An implementation of Apache::Session::Store

SYNOPSIS

use Apache::Session::Browseable::Redis;

tie %hash, 'Apache::Session::Browseable::Redis', $id, {
   # optional: default to localhost
   server => '127.0.0.1:6379',

   # optional: set a Redis TTL (in seconds) on session keys
   TTL => 86400,
};

DESCRIPTION

This module is an implementation of Apache::Session::Browseable. It uses the Redis storage system.

OPTIONS

TTL

Optional. If set, session keys will be stored with a Redis TTL (in seconds) using SET key value EX ttl. The TTL is refreshed on every update. This acts as a safety net: sessions are automatically removed by Redis if the application fails to delete them. Index sets are not expired by Redis, but orphan index entries will be cleaned up by searchOn or manual maintenance.

Without this option, session keys have no expiration and must be explicitly deleted or purged.

SEE ALSO

Apache::Session::Browseable, Apache::Session::NoSQL, Apache::Session

COPYRIGHT AND LICENSE

2009-2025 by Xavier Guimard
2013-2025 by Clément Oudot
2019-2025 by Maxime Besson
2013-2025 by Worteks
2023-2025 by Linagora

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself, either Perl version 5.10.1 or, at your option, any later version of Perl 5 you may have available.

1 POD Error

The following errors were encountered while parsing the POD:

Around line 217:

Non-ASCII character seen before =encoding in 'Clément'. Assuming UTF-8